==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MaskInputBase } from "./MaskInputBase";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var MaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MaskInput, _super);
    function MaskInput() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MaskInput.prototype, "ae", {
        get: function () {
            var ret_ = this.f.m("valueMode");
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, this.f.f(MaskInputValueMode_$type, ret_)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("valueMode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ag", {
        get: function () {
            var ret_ = this.f.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "af", {
        get: function () {
            var ret_ = this.f.m("mask");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("mask", value_);
        },
        enumerable: false,
        configurable: true
    });
    MaskInput.prototype.ai = function () {
        this.nativeElement.reportValidity();
    };
    MaskInput.prototype.ah = function () {
        this.nativeElement.checkValidity();
    };
    MaskInput.$t = markType(MaskInput, 'MaskInput', MaskInputBase.$);
    return MaskInput;
}(MaskInputBase));
export { MaskInput };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MaskInputBase } from "./MaskInputBase";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var MaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MaskInput, _super);
    function MaskInput() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MaskInput.prototype, "af", {
        get: function () {
            var ret_ = this.f.n("valueMode");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, this.f.f(MaskInputValueMode_$type, ret_)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("valueMode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ah", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ag", {
        get: function () {
            var ret_ = this.f.n("mask");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("mask", value_);
        },
        enumerable: false,
        configurable: true
    });
    MaskInput.prototype.ai = function () {
        this.nativeElement.connectedCallback();
    };
    MaskInput.$t = markType(MaskInput, 'MaskInput', MaskInputBase.$);
    return MaskInput;
}(MaskInputBase));
export { MaskInput };
